@@ -1,8 +1,7 @@
 import json
 
-from b_lambda_layer_common.source.python.b_lambda_layer_common.api_gateway.cognito_access_token import \
-    CognitoAccessToken
-from b_lambda_layer_common_test.unit.api_gateway import root
+from b_lambda_layer_common.api_gateway.cognito_access_token import CognitoAccessToken
+from . import root
 
 
 def test_FUNC_username_WITH_dummy_lambda_event_EXPECT_successfully_extracted_username():
